==> emphase-0.0.18.tgz: package/src/languages/em_swift.js <==
var lang = {
    name: "swift",
    friendlyName: "Swift",
    keywords: [
        "class",
        "deinit",
        "enum",
        "extension",
        "func",
        "import",
        "init",
        "internal",
        "let",
        "operator",
        "private",
        "protocol",
        "public",
        "static",
        "struct",
        "subscript",
        "typealias",
        "var",
        "break",
        "case",
        "continue",
        "default",
        "do",
        "else",
        "fallthrough",
        "for",
        "if",
        "in",
        "return",
        "switch",
        "where",
        "while",
        "as",
        "dynamicType",
        "is",
        "nil",
        "self",
        "super",
        "_COLUMN_",
        "_FILE_",
        "_FUNCTION_",
        "_LINE_",
        "associativity",
        "convenience",
        "dynamic",
        "didSet",
        "final",
        "get",
        "infix",
        "inout",
        "lazy",
        "left",
        "mutating",
        "none",
        "nonmutating",
        "optional",
        "override",
        "postfix",
        "precedence",
        "prefix",
        "Protocol",
        "required",
        "right",
        "set",
        "type",
        "unowned",
        "weak",
        "willSet"
    ],
    values: [
        "false",
        "true"
    ],
    comment: "//",
    multiLineComment: [{init: "/*", term: "*/", esc: "*"}],
    multiLineString: [],
    directives: [],
    directives_s: []
};
if (typeof window !== "undefined") { null==window._em_la_&&(window._em_la_={}),lang.name in Object.keys(window._em_la_)||(window._em_la_[lang.name]=lang); } else { module.exports = lang }

==> emphase-0.0.25.tgz: package/src/languages/em_swift.js <==
var lang = {
    name: "swift",
    fnam: "Swift",
    kwds: [
        "class",
        "deinit",
        "enum",
        "extension",
        "func",
        "import",
        "init",
        "internal",
        "let",
        "operator",
        "private",
        "protocol",
        "public",
        "static",
        "struct",
        "subscript",
        "typealias",
        "var",
        "break",
        "case",
        "continue",
        "default",
        "do",
        "else",
        "fallthrough",
        "for",
        "if",
        "in",
        "return",
        "switch",
        "where",
        "while",
        "as",
        "dynamicType",
        "is",
        "nil",
        "self",
        "super",
        "_COLUMN_",
        "_FILE_",
        "_FUNCTION_",
        "_LINE_",
        "associativity",
        "convenience",
        "dynamic",
        "didSet",
        "final",
        "get",
        "infix",
        "inout",
        "lazy",
        "left",
        "mutating",
        "none",
        "nonmutating",
        "optional",
        "override",
        "postfix",
        "precedence",
        "prefix",
        "Protocol",
        "required",
        "right",
        "set",
        "type",
        "unowned",
        "weak",
        "willSet"
    ],
    lval: [
        "false",
        "true"
    ],
    cmts: "//",
    cmtb: [{init: "/*", term: "*/", esc: "*"}],
    strb: [],
    dcvn: [],
    dcvs: []
};
if (typeof window !== "undefined") { null==window._em_la_&&(window._em_la_={}),lang.name in Object.keys(window._em_la_)||(window._em_la_[lang.name]=lang); } else { module.exports = lang }
